Device

Struct Device 

pub struct Device { /* private fields */ }
A handle to a Device.

A device contains zero or more keys.

Some backends manage multiple physical devices. For instance, the smartcard backend exposes each smartcard as a separate device. Other backends use the device abstraction to logically group related keys together. For instance, the soft keys backend exposes each certificate as a separate device.

Implementations

Source

impl Device

pub fn id(&mut self) -> Result<String>

Returns the device’s ID.

pub async fn id_async(&mut self) -> Result<String>

Returns the device’s ID.

pub fn keys(&mut self) -> Result<Vec<Key>>

List keys on a device.

Lists the keys on the device.

Some of the returned keys may be known, but not currently available. For instance, if a smartcard is not plugged in, or an ssh connection is not established.

pub async fn keys_async(&mut self) -> Result<Vec<Key>>

List keys on a device.

Lists the keys on the device.

Some of the returned keys may be known, but not currently available. For instance, if a smartcard is not plugged in, or an ssh connection is not established.